# $Id: README.txt 2019-06-05 $
# Author: Zhipeng Zhao <zhzhao@microsoft.com>
# Copyright: .

"""
AZURE SENTINEL NOTEBOOKS PYTHON TOOLS
======================================
This package is developed to support Azure Sentinel Notebooks.  It is in an early preview stage so please provide feedback, report bugs, and suggets for new features.

INSTALL
=======
!pip install Azure-Sentinel-Utilities

"""

__docformat__ = 'restructuredtext'